#
# spec file for package rdiff-backup
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020 B1 Systems GmbH, Vohburg, Germany
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           rdiff-backup
Version:        2.2.6
Release:        bp160.1.10
Summary:        Convenient and transparent local/remote incremental mirror/backup
License:        GPL-2.0-or-later
Group:          Productivity/Archiving/Backup
URL:            https://rdiff-backup.net/
Source0:        https://github.com/rdiff-backup/rdiff-backup/releases/download/v%{version}/rdiff-backup-%{version}.tar.gz
#
BuildRequires:  librsync-devel
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
BuildRequires:  python3-setuptools_scm
BuildRequires:  rubygem(asciidoctor)
Requires:       python3-PyYAML
Requires:       python3-pylibacl
Requires:       python3-xattr
%if %{python_version_nodots} < 38
# boo#1219652
Requires:       python3-importlib-metadata
%endif

%description
rdiff-backup backs up one directory to another, possibly over a
network. The target directory ends up a copy of the source directory,
but extra reverse diffs are stored in a special subdirectory of that
target directory, so you can still recover files lost some time ago.
The idea is to combine the best features of a mirror and an incremental
backup. rdiff-backup also preserves subdirectories, hard links, dev
files, permissions, uid/gid ownership, and modification times. Also,
rdiff-backup can operate in a bandwidth efficient manner over a pipe,
like rsync. Thus you can use rdiff-backup and ssh to securely back a
hard drive up to a remote location, and only the differences will be
transmitted. Finally, rdiff-backup is easy to use and settings have
sensical defaults.

%prep
%setup -q
%autopatch -p1

%build
export CFLAGS="%{optflags}"
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root %{buildroot}
rm -rf %{buildroot}%{_datadir}/doc/rdiff-backup

%files
%license COPYING
%doc CHANGELOG.adoc docs/FAQ.adoc docs/examples.adoc docs/index.adoc README.adoc
%{_mandir}/*/*
%{_bindir}/*
%{python3_sitearch}/rdiff_backup
%{python3_sitearch}/rdiffbackup
%{python3_sitearch}/*.egg-info
%dir %{_datadir}/bash-completion
%dir %{_datadir}/bash-completion/completions
%{_datadir}/bash-completion/completions/rdiff-backup

%changelog
* Wed Feb  7 2024 Stefan Seyfried <seife+obs@b1-systems.com>
- require python3-importlib-metadata for python < 3.8 (boo#1219652)
* Mon Sep 11 2023 Paolo Stivanin <info@paolostivanin.com>
- Update to 2.2.6:
  * FIX: extended variables were not correctly written if content of file
    hadn't changed and file was read-only (API 201).
  * FIX: failed parsing of arguments would return code 2 for warnings
    instead of 1 for errors
  * FIX: quoting variables where not correctly propagated when set from
    the command line (API 201).
  * FIX: some new functions were needed with higher security level and
    had to be sorted accordingly (API 201).
  * FIX: test action would fail with empty error message when using API
    201
  * FIX: timezone was not always correctly calculated in countries with
    historically changing DST, closes #902
  * NEW: add environment variable RDIFF_BACKUP_API_VERSION to
    artificially modify the API version dictionary, see the man page for
    details.
  * NEW: add warning that server will be called with deprecated CLI and
    how to avoid the corresponding warning (see also the FAQ)
  * NEW: there is now a weekly release with changelog for intermediate
    testing available at
    https://github.com/rdiff-backup/rdiff-backup/releases/tag/weekly
  * FIX: cross-version issue with 2.0.5 complaining about KeyError
    restrict_path, closes #872
  * FIX: fail gracefully when connection(s) can't be setup e.g. in case
    of network error, closes #868
* Thu Mar 30 2023 Petr Vorel <pvorel@suse.cz>
- Require python3-PyYAML, python3-pylibacl, python3-xattr
  (the latter two were Recommends only; all are runtime dependencies).
* Mon Mar 27 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.4:
  * Only very small code and documentation fixes, hopefully
    really the last fix release of the stable branch 2.2, before
    the development effort for v2.4 starts.
* Fri Feb 10 2023 Dirk Müller <dmueller@suse.com>
- update to 2.2.3:
  * Only small code and documentation fixes and additions,
    probably the last fix release of the stable branch 2.2,
    before the development effort for v2.4 starts.
  * That's embarrassing but the last version still had a glitch
    and the sdist package `rdiff-backup-2.2.2.tar.gz` didn't
    contain the pre-rendered man-pages which some packagers
    requested.
* Tue Dec 20 2022 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- Happy Holidays release v2.2.0
- Despite all these changes, rdiff-backup 2.2 remains compatible with
  rdiff-backup 2.0, but you can, and are encouraged to, use the new API
  using --api-version 201, enabling two additional features:
  * there is at last a --help parameter
  * the CLI (Command Line Interface) has been refurbished and modernized
    (the old one is still present but deprecated)
  * You can store your parameters in a file, one per line, and call
    rdiff-backup @myfile to use them
  * Verbosity levels and error codes have been standardized for clearer
    interaction with the tool
  * Last backup can be regressed even if it isn't failed
  * Locking of repositories has been greatly improved
* Thu Sep 17 2020 Paolo Stivanin <info@paolostivanin.com>
- update to 2.0.5:
  * CHG: explicitly refuse to back-up to exFAT because it doesn't
    handle properly case insensitive deletion of files
  * CHG: testing explicitly for existence of tempdir might make
    certain setups fail now because tempdir was silently ignored
  * DEV: Add a misc script to setup an ArchLinux as development
    platform
  * DEV: fix compatibility in rollsum and sum-size with rdiff
    2.2/2.3 leading to errors in librsynctest
  * DEV: function rpath.getdevnums now also returns the device
    type, block or char
  * DEV: replace deprecated xattr.xattr with xattr. function
  * FIX: address PY_SSIZE_T deprecation warning appearing
    under Python 3.8 in the C code
  * FIX: avoid TypeError: a bytes-like object is required,
    not 'str' when logging error message by fixing encoding
  * FIX: explicitly test existence of tempdir and avoid "Can't
    mix strings and bytes in path components" error
  * FIX: failed on certain device files with no such file
    or directory error
  * FIX: Force encoding of log file to be UTF-8 on all platforms
    and be lenient to avoid codec errors on logging
* Tue May 19 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- update to 2.0.3:
  changes in behaviour:
  * multimedia files with extensions ogv, oga, ogm and mkv are not
    compressed any more.
  * return error code 2 instead of number of failed files during
    repo verification to have a consistent return code (1 is any
    other kind of error, 0 if everything is well), closes #338
  bug fixes:
  * handle include/exclude files with Windows/DOS endings
    properly, closes #357
  * allow backup from and to Windows shares again, closes #337
  * avoid IndexError: string index out of range error when using
    accentuated characters in exclude/include patterns, closes #340
  * avoid test error when using librsync >= 2.2 by adding -R
    rollsum to rdiff call in librsynctest, closes #304
  * fail with meaningful error message on metadata mirror files
    with duplicate timestamps, closes #322
  * sequence of exception leading to abort when logging tuple
    of bytes because of unreachable directory, closes #310
  new features:
  * create a new rdiff-backup-delete script which can remove a file
    and all its history from a backup repository (use with care).
  * add option --allow-duplicate-timestamps to only warn about
    duplicate timestamps in metadata mirror files, use this option
    with care and only to clean an impacted backup repository.
* Sun Mar 15 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- update to 2.0.0:
  * FIX: Add workaround to avoid error when backup directory is
    under the source directory (github issue #296)
  * FIX: bytestotime() should return None on decode failure
    (Closes github issue #295)
* Sat Mar 14 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- update to 1.9.2rc0, first rc for 2.0.0:
  * FIX: UpdateError: Updated mirror temp file does not match
    source, Closes github issue #237
  * FIX: do not fail when starting with uid/gid equal to maximum,
    avoid OverflowError on os.chown
* Sun Feb 23 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- update to 1.9.1b0, third beta before 2.0.0:
  * avoid double unquoting of increment file infos, closes #266
  * fix some ugly bytes output in strings, closes #238
  * improved hardink handling, Closes #239
  * add support for SOURCE_DATE_EPOCH to override the build date
  * add efficient sparse file handling
- remove all (upstreamed) patches:
  * 0001-handle-sparse-files-efficiently.patch
  * Hardlink.py.revised-1.4.0.patch
  * compare.py-1.4.0.patch
  * rdiff-backup-1.9-reproducible.diff
* Fri Feb  7 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- add rdiff-backup-1.9-reproducible.diff for reproducible build
* Sat Feb  1 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- update to 1.9.0b0, second beta before 2.0.0
- remove upstreamed patches:
  - 0001-add-compatibility-with-python-xattr.patch
  - 0001-metadata-handle-unknown-group-ids-from-file-system.patch
* Sat Jan 25 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- remove 0001-fix-invalid-type-in-ea.read_from_rp.patch, add
  0001-add-compatibility-with-python-xattr.patch as a better fix
* Fri Jan 24 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- update 0001-handle-sparse-files-efficiently.patch, simplify
  sparse file handling
* Thu Jan 23 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- add two python3 fixes:
  - 0001-fix-invalid-type-in-ea.read_from_rp.patch
  - 0001-metadata-handle-unknown-group-ids-from-file-system.patch
- replace two sparse patches rdiff-backup-1.4.0-sparsefiles.diff
  and rdiff-backup-1.4.0-sparse-no-seek-in-gzip.diff with the
  upstream-submitted 0001-handle-sparse-files-efficiently.patch
* Wed Jan 22 2020 Stefan Seyfried <seife+obs@b1-systems.com>
- update to version 1.4.0beta0
  - port to python3
  - many others fixes, see CHANGELOG
- Patches rebased:
  - removed Hardlink.py.revised-patch
  - removed compare.py.patch
  - removed rdiff-backup-1.2.8-sparsefiles.diff
  - removed rdiff-backup-1.2.8-sparse-no-seek-in-gzip.diff
  - added Hardlink.py.revised-1.4.0.patch
  - added compare.py-1.4.0.patch
  - added rdiff-backup-1.4.0-sparsefiles.diff
  - added rdiff-backup-1.4.0-sparse-no-seek-in-gzip.diff
- Patches removed (included upstream):
  - rdiff-backup-fix-deprecations.diff
  - rdiff-backup-dont-pick-empty-sessions.diff
  - rdiff-backup-librsync-1.0.patch
- reorder spec file, get rid of conditions for pre 12.1
- remove old signature and keyring
* Mon Mar 16 2015 dimstar@opensuse.org
- Add rdiff-backup-librsync-1.0.patch: Fix build with
  librsync 1.0.0.
* Fri Mar 13 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Add gpg signature
* Mon Jun 30 2014 seife+obs@b1-systems.com
- add rdiff-backup-1.2.8-sparse-no-seek-in-gzip.diff:
  the sparse code makes no sense in gzip compressed case and it
  triggers an IO error in gzip.py when trying to seek backwards
* Wed Apr 23 2014 hpj@urpla.net
- apply rdiff-backup-dont-pick-empty-sessions.diff:
  don't take empty sessions into account, which has the potential of
  removing valid backups with --remove-older-than xB, while keeping
  empty/useless sessions instead
* Fri Feb 14 2014 seife+obs@b1-systems.com
- add rdiff-backup-1.2.8-sparsefiles.diff to efficiently back up
  sparse files (found on rdiff-backup mailing list)
* Thu Nov 14 2013 hpj@urpla.net
- fix hardlink issue: http://savannah.nongnu.org/bugs/?26848
  - apply Joe Steeles patches to resolve it:
  * Hardlink.py.revised-patch
  * compare.py.patch
* Fri Mar 15 2013 hpj@urpla.net
- fix os.popen2 deprecation
- add recommends for python-xattr and python-pylibacl
* Mon Feb 20 2012 boris@steki.net
- fixed building on Factory as librsync is now split into lib and devel package
* Thu Sep  3 2009 poeml@suse.de
- update to 1.2.8
  New in v1.2.8:
  * Improve handling of incorrect permissions on backup repository during restore
    operation. Closes Ubuntu bug #329722. (Andrew Ferguson)
  * Don't crash on zlib errors. Closes Debian bug #518531. (Andrew Ferguson)
  * Make sticky bit warnings quieter while determining file system abilities.
    Closes Savannah bug #25788. (Andrew Ferguson)
  * Fix situation where destination file cannot be opened because of an access
    error. Thanks to Dean Cording for the bug report. (Andrew Ferguson)
  * Fix --compare-hash options on Windows. Thanks to Serge Zub for the fix.
  New in v1.2.7:
  * Don't crash when filesystem can't set ACL. Thanks to Matt Thompson for the bug
    report. (Andrew Ferguson)
  * Properly disable hardlinks by default on Windows.
  * Fix Python 2.2 compatibility. Closes Savannah bug #25529. (Andrew Ferguson)
  * Fix typo which caused failure when checking if another rdiff-backup process is
    running on Windows. Thanks to Ryan Hughes for the bug report. (Andrew Ferguson)
* Fri Feb 13 2009 puzel@suse.cz
- update to 1.2.6
  - too many changes to be listed here, please see
    /usr/share/doc/packages/rdiff-backup/CHANGELOG
  for details
* Tue Aug 26 2008 cthiel@suse.de
- update to version 1.2.1
  * Produce a new binary for Windows which includes the Python for Windows
    Extensions.
  * Disable hardlinks by default when backup source or restore destination
    is on Windows.
  * Properly catch KeyboardInterrupt on Python 2.5.
  * Don't crash if a CacheIndexable tries to clear a non-existent cache
    entry, since the entry must already be cleared.
* Mon Aug  4 2008 cthiel@suse.de
- update to version 1.2.0
  * This is the new stable branch of rdiff-backup, representing almost three
    years of development releases. From the previous development release, this
    release includes two fixes for Unicode issues. From the previous stable
    release, this release features a large number of new features, including
    SHA1 checksums, native Windows support, improved Mac OS X and Cygwin
    support, better filesystem support for HFS+, NFS, SSHFS, SMB, CIFS, AFS,
    NTFS, and FAT32, and better handling of unreadable or pathological file
    permissions. It also includes the previously separate
    'rdiff-backup-statistics' tool.
* Tue Jan  9 2007 cthiel@suse.de
- fix ICC warning:  warning #592: variable "return_val" is used before its
  value is set (#232824)
* Mon Jan  8 2007 cthiel@suse.de
- update to version 1.0.5
  * Fix a traceback due to an off-by-1 error in "--remove-older-than nB".
  * Fix a security violation when restoring from a remote repository.
  * --list-at-time, --list-increments, and --list-increment-sizes should now
    work from a read-only repository.
* Mon Oct  2 2006 cthiel@suse.de
- fix build on older distributions
* Thu Sep 21 2006 cthiel@suse.de
- fix build with python 2.5
* Tue Feb 28 2006 jmatejek@suse.cz
- updated to reflect python changes due to #149809
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 23 2006 cthiel@suse.de
- update to version 1.0.4
* Sat Nov 26 2005 cthiel@suse.de
- update to version 1.0.3
* Wed Oct 26 2005 cthiel@suse.de
- update to version 1.0.2
* Tue Sep 13 2005 cthiel@suse.de
- update to version 1.0.1
- specfile cleanup
* Wed Aug 17 2005 cthiel@suse.de
- update to version 1.0.0
* Sun Aug 14 2005 cthiel@suse.de
- use %%py_requires macro
* Tue May  3 2005 cthiel@suse.de
- use %%py_sitedir macro
* Fri Apr 15 2005 cthiel@suse.de
- initial creation of package (0.12.8)
